@@ -426,7 +426,7 @@ make_row_for_event_data (GcalSearchView  *view,
     }
 
   /* lock icon */
-  if (gcal_manager_is_client_writable (priv->manager, data->source))
+  if (!gcal_manager_is_client_writable (priv->manager, data->source))
     {
       GtkWidget *lock_icon;
 
@@ -639,17 +639,10 @@ gcal_search_view_component_added (ECalDataModelSubscriber *subscriber,
   RowEventData *row_data;
   GcalEventData *data;
   ECalComponentId *id;
-  ECalComponentDateTime dt;
   gchar *uuid;
 
   priv = gcal_search_view_get_instance_private (GCAL_SEARCH_VIEW (subscriber));
 
-  e_cal_component_get_dtstart (comp, &dt);
-
-  /* Protect against NULL start date */
-  if (dt.value == NULL)
-    return;
-
   /* event data */
   data = g_new0 (GcalEventData, 1);
   data->source = e_client_get_source (E_CLIENT (client));
@@ -679,8 +672,6 @@ gcal_search_view_component_added (ECalDataModelSubscriber *subscriber,
   priv->num_results++;
 
   update_view (GCAL_SEARCH_VIEW (subscriber));
-
-  e_cal_component_free_datetime (&dt);
 }
 
 static void
