@@ -247,7 +247,7 @@ add_event_to_day_array (GcalYearView  *year_view,
   priv = year_view->priv;
   child_widget = gcal_event_widget_new_from_data (event_data);
   gcal_event_widget_set_read_only (GCAL_EVENT_WIDGET (child_widget),
-                                   gcal_manager_is_client_writable (priv->manager, event_data->source));
+                                   !gcal_manager_is_client_writable (priv->manager, event_data->source));
 
   dt_start = gcal_event_widget_peek_start_date (GCAL_EVENT_WIDGET (child_widget));
   dt_end = gcal_event_widget_peek_end_date (GCAL_EVENT_WIDGET (child_widget));
@@ -545,12 +545,7 @@ draw_month_grid (GcalYearView *year_view,
   x = priv->navigator_grid->coordinates[month_nr].x;
   y = priv->navigator_grid->coordinates[month_nr].y;
 
-  /* Get the font description */
-  gtk_style_context_save (context);
-  gtk_style_context_set_state (context, state_flags | GTK_STATE_FLAG_SELECTED);
   gtk_style_context_get (context, state_flags | GTK_STATE_FLAG_SELECTED, "font", &sfont_desc, NULL);
-  gtk_style_context_restore (context);
-
   slayout = gtk_widget_create_pango_layout (widget, NULL);
   pango_layout_set_font_description (slayout, sfont_desc);
 
@@ -932,6 +927,9 @@ add_event_clicked_cb (GcalYearView *year_view,
   GcalYearViewPrivate *priv = year_view->priv;
   icaltimetype *start_date, *end_date = NULL;
 
+  if (priv->popover_mode)
+    gtk_widget_hide (priv->popover);
+
   if (priv->start_selected_date->day == 0)
     {
       start_date = gcal_dup_icaltime (priv->current_date);
@@ -945,9 +943,6 @@ add_event_clicked_cb (GcalYearView *year_view,
       end_date->is_date = 1;
     }
 
-  if (priv->popover_mode)
-    gtk_widget_hide (priv->popover);
-
   start_date->is_date = 1;
   g_signal_emit_by_name (GCAL_VIEW (year_view), "create-event-detailed", start_date, end_date);
   g_free (start_date);
